package wekan.wrapper.entity;

import com.google.gson.annotations.SerializedName;

public class BoardPrototype {
    private String title;
    private String owner;
    private boolean isAdmin;
    private boolean isActive;
    private boolean isNoComments;
    private boolean isCommentOnly;
    private Permission permission;
    @SerializedName("color")
    private BoardBackgroundColor backgroundColor;

    private BoardPrototype(
            String title,
            String owner,
            boolean isAdmin,
            boolean isActive,
            boolean isNoComments,
            boolean isCommentOnly,
            Permission permission,
            BoardBackgroundColor backgroundColor
    ) {
        this.title = title;
        this.owner = owner;
        this.isAdmin = isAdmin;
        this.isActive = isActive;
        this.isNoComments = isNoComments;
        this.isCommentOnly = isCommentOnly;
        this.permission = permission;
        this.backgroundColor = backgroundColor;
    }

    public static class Builder {
        private String title;
        private String owner;
        private boolean isAdmin = true;
        private boolean isActive = true;
        private boolean isNoComments = false;
        private boolean isCommentOnly = false;
        private Permission permission = Permission.PRIVATE;
        private BoardBackgroundColor backgroundColor = BoardBackgroundColor.BELIZE;

        public Builder() {
        }

        public BoardPrototype build() {
            return new BoardPrototype(
                    title,
                    owner,
                    isAdmin,
                    isActive,
                    isNoComments,
                    isCommentOnly,
                    permission,
                    backgroundColor
            );
        }

        public Builder setTitle(String title) {
            this.title = title;
            return this;
        }

        public Builder setOwner(String owner) {
            this.owner = owner;
            return this;
        }

        public Builder setAdmin(boolean admin) {
            isAdmin = admin;
            return this;
        }

        public Builder setActive(boolean active) {
            isActive = active;
            return this;
        }

        public Builder setNoComments(boolean noComments) {
            isNoComments = noComments;
            return this;
        }

        public Builder setCommentOnly(boolean commentOnly) {
            isCommentOnly = commentOnly;
            return this;
        }

        public Builder setPermission(Permission permission) {
            this.permission = permission;
            return this;
        }

        public Builder setBackgroundColor(BoardBackgroundColor backgroundColor) {
            this.backgroundColor = backgroundColor;
            return this;
        }
    }
}


